{% load staticfiles %}{% load compress %}
<!DOCTYPE html>
<html lang="en">
    <head>
        <title>MySmile – simple CMS based on Django!</title>
        
        <meta charset="UTF-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        
        <link rel="shortcut icon" href="{% static 'themes/'|add:MYSMILE_THEME|add:'/favicon.ico' %}" />
        {% block apple-touch-icon-precomposed %}
        {% endblock %}

        {% compress css %}
        <link href="{% static 'vendor/bootstrap/dist/css/bootstrap.min.css' %}" rel="stylesheet">
        <link href="{% static 'themes/'|add:MYSMILE_THEME|add:'/css/main.css' %}" rel="stylesheet">
        {% endcompress %}

        {% block css %}{% endblock %}
        {% block js %}{% endblock %}
        {% block google_analytics %} {% endblock %}
    </head>
    <body>
        <nav class="navbar navbar-default">
          <div class="container">
            <!-- Brand and toggle get grouped for better mobile display -->
            <div class="navbar-header">
              <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navigationbar">
                <span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
              </button>
                {% block logo %}
                {% endblock %}

            </div>

            <!-- Collect the nav links, forms, and other content for toggling -->
            <div id="navigationbar" class="collapse navbar-collapse">
              {% block main_nav %}
              {% endblock %}

              {% block flags %}
              {% endblock %}

            </div><!-- /.navbar-collapse -->
          </div><!-- /.container -->
        </nav> 
       
        <div class="page-container">
            <div class="container">
                <!-- navbar-inline -->
                <div class="pull-right">
                    {% block additional_nav %}
                    {% endblock %}
                </div><!-- /.pull-right -->

                <!-- page content -->
                <div class="page-header">
                    {% block col_central_header %}
                    {% endblock %}
                </div>

                <!-- right column -->
                {% if page__photo or youtube or col_right %}

                <aside class="pull-right well">
                    {% block col_right %}
                    {% endblock %}
                </aside>
                {% endif %}

                {% block col_central %}
                {% endblock %}
            </div><!-- /container -->

            {% if bottom_cols  %}
            <div class="container">
              <!-- bottom columns -->
              <div class="row">
                {% if bottom_cols|length == 3 %}
                  {% for col in bottom_cols %}
                    <div class="col-md-4">{{ col|safe }}</div>
                  {% endfor %}

                {% elif bottom_cols|length == 2 %}
                  {% for col in bottom_cols %}
                    <div class="col-md-6">{{ col|safe }}</div>
                  {% endfor %}

                {% else %}
                  {% for col in bottom_cols %}
                    <div class="col-md-12">{{ col|safe }}</div>
                  {% endfor %}
                {% endif %}
              </div>
            </div> <!-- /container -->
            {% endif %}
        </div><!-- /page-container -->


        <footer class="footer">
            <div class="container">
                <div class="pull-left">
                    {% block contact %}
                    {% endblock %}
                </div>  
                    
                <div class="pull-right">
                    <p class="text-muted">&copy; 2012&ndash;{% now "Y" %} MySmile, all right reserved</p>
                </div>    
            </div>
        </footer>
        
        <!-- Bootstrap core JavaScript
        ================================================== -->
        {% compress js %}
        <script src="{% static 'vendor/jquery/dist/jquery.min.js' %}"></script>
        <script src="{% static 'vendor/bootstrap/dist/js/bootstrap.min.js' %}"></script>
        {% endcompress %}
    </body>
<!-- page cached at {% now "jS F Y H:i" %} -->
</html>
