{% load staticfiles %}{% load compress %}<!DOCTYPE html>
<html lang="{{ lang|lower }}">
    <head>
        <link rel="shortcut icon" href="{% static 'themes/'|add:MYSMILE_THEME|add:'/favicon.ico' %}" />
        {% block apple-touch-icon-precomposed %}{% endblock %}
        <meta charset="UTF-8">
        <meta name="description" content="{{ meta_description }}"  />
        <meta name="keywords" content="{{ meta_keywords }}" />
        <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=5">
        <meta name="author" content="{{ meta_author }}">
        <title>{{ meta_title }}</title>

        {% compress css %}
        <link rel="stylesheet" href="{% static 'vendor/pure/pure-min.css' %}">
        <!--[if lte IE 8]>
            <link rel="stylesheet" href="{% static 'vendor/pure/grids-responsive-old-ie-min.css' %}">
        <![endif]-->
        <!--[if gt IE 8]><!-->
            <link rel="stylesheet" href="{% static 'vendor/pure/grids-responsive-min.css' %}">
        <!--<![endif]-->
        
        <link rel="stylesheet" href="{% static 'themes/'|add:MYSMILE_THEME|add:'/css/main.css' %}">
        <link rel="stylesheet" href="{% static 'themes/'|add:MYSMILE_THEME|add:'/css/extras.css' %}">
        {% endcompress %}

        <style>
            .line_left_color{               
                background: {{ page__color }}; 
                background: -moz-linear-gradient(top, {{ page__color }}, #FFF); 
                background: -webkit-gradient(linear, left top, left bottom, 
                color-stop(0%,{{ page__color }}), color-stop(100%,#FFF));
                background: -webkit-linear-gradient(top, {{ page__color }}, #FFF);
                background: -o-linear-gradient(top, {{ page__color }}, #FFF); 
                background: -ms-linear-gradient(top, {{ page__color }}, #FFF); 
                background: linear-gradient(top, {{ page__color }}, #FFF);  
            }
            #mnav .active { background-color:  {{ page__color }}; }
            #inav .active a { border-bottom: 2px solid {{ page__color }}; } 
            #inav ul li:hover { border-bottom: 2px solid {{ page__color }}; }

        </style>
        
        {% block css %}{% endblock %}
        {% block js %}{% endblock %}
        {% block google_analytics %} {% endblock %}
    </head>
<body>
<div id="layout">
    <header class="pure-g">
        <div id="logo" class="pure-u-3-24">
            {% block logo %}
            {% endblock %}
        </div>
            
        <div class="pure-u-21-24">
                
            <div id="line_top" class="pure-u-1" style="background-color: {{ page__color }};">
                <div id="flags">{% block flags %}{% endblock %}</div>
            </div>

            <div class="pure-u-md-18-24">
                <nav id="mnav" class="pure-u-18-24 pure-menu pure-menu-open pure-menu-horizontal">{% block main_nav %}{% endblock %}</nav>
                {% if inav|length > 0  %}
                    <nav id="inav" class="pure-u-18-24">{% block additional_nav %}{% endblock %}</nav>
                {% endif %}
            </div>
            <div id="contact" class="pure-u-md-6-24">{% block contact %}{% endblock %}</div>
            
        </div>
            
    </header>

    <main class="pure-g">
        <article class="pure-u-1">
            <div id="line_left" class="line_left_color"></div>

            {% if col_right or page__photo or youtube %}
            <aside id="col_right">
                {% block col_right %}{% endblock %}
            </aside>
            {% endif %}
            <div id="col_central_text">{% block col_central %}{% endblock %}</div>
        </article>

        {% if bottom_cols  %}
        <article id="col_bottom" class="pure-g">
                {% for col in bottom_cols %}
                    <aside class="pure-u-1 pure-u-md-1-{{ bottom_cols|length }}"><div>{{ col|safe }}</div></aside>
                {% endfor %}
        </article>
        {% endif %}
    </main>

    <footer class="pure-g">
        <nav id="fnav" class="pure-u-md-18-24">
           <ul>
                {% for item in main_menu %}
                    <li><a href="/{{ lang }}/{{ item.page__slug }}.html">{{ item.menu }}</a></li>
                {% endfor %}
            </ul>
        </nav>
        <div id="copyright" class="pure-u-md-6-24"><span>&copy; copyright 2012&ndash;{% now "Y" %}</span></div>
    </footer> 

<div id="line_bottom"></div><div class="clear"></div>

{% block advertisement %} {% endblock %}
</div>
</body>
<!-- page cached at {% now "jS F Y H:i" %} -->
</html>
