/* Column right
-------------------------------------------------- */
aside {
    margin: 0 0 10px 10px;
    width: 33.37%;
}

aside img{
    display: block;
    margin: 0 auto;
}


/* Page header styles
-------------------------------------------------- */
.page-header {
    padding-bottom: 9px;
    margin: 0 0 10px;
    border-bottom: none;
}


/* Navbar styles
-------------------------------------------------- */

.navbar-default {
    background-color: #FFE9CE;
    border-color: #FFD7A7;
}

.navbar-brand {
    padding: 0 15px;
}

.navbar-default .navbar-nav>.active>a, .navbar-default .navbar-nav>.active>a:focus, .navbar-default .navbar-nav>.active>a:hover {
    color: #555;
    background-color: #FFD7A7;
}

.navbar-translate li {
    float: left;
}

.navbar-translate>li>a {
    padding-bottom: 10px;
}

/* Sticky footer styles
-------------------------------------------------- */
.page-container {
    padding-bottom: 110px; /* related with height of the footer */
}

/* Sticky footer styles
-------------------------------------------------- */
html {
    position: relative;
    min-height: 100%;
}

body {
    /* Margin bottom by footer height */
    margin-bottom: 60px;
}

.footer {
    position: absolute;
    bottom: 0;
    width: 100%;
    /* Set the fixed height of the footer here */
    height: 140px;
    background-color: #f5f5f5;
    border-top: 1px solid #e3e3e3;
}

.footer .container .text-muted {
    margin: 20px 0;
}
