{% load i18n %}
<form action="/i18n/setlang/" method="post" style="display: inline;"> {% csrf_token %}
  <div style="display: inline;">
	<select name="language" onchange="javascript:form.submit()">
	  {% for lang in LANGUAGES %}
		<option value="{{ lang.0 }}"{% ifequal LANGUAGE_CODE lang.0 %} selected="selected"{% endifequal %}>{{ lang.1 }}</option>
	  {% endfor %}
	</select>
  </div>
</form>
